function [ order ] = Ordering_fn( weightMat, dir_flag )
%Ordering_fn implements the ward order algorithm as described by 
% Wong/Watkinson/Wu.
% WEIGHTMAT is an nxn matrix (n = number of wards + dummy ward (END)
% + dummy ward (START)). The
% element (i,j) represents the number of patient moving from ward i
% to ward j in a given timeframe.
%
% DIRECTORATE is a cell array containing wards in the same group. e.g.
% directorate{1} = [1,2,6], directorate{2} = [3,4,5] splits the wards into
% two groups
%
% DIR_FLAG, is a boolean that determines whether the directorate
% extension (taking into account ward clusters) is used.
%
% ORDER is the recommended order for introducing wards to
% the new electronic system.
numWards = length(weightMat);
order =[];
wardChosen = 0;

while wardChosen ~= numWards - 1 
    outDegrees = sum(weightMat,2);
    inDegrees = sum(weightMat,1);
    if dir_flag
        wardChosen = evalDisruption(directorate(weightMat, order);
    else
        wardChosen = evalDisruption(outDegrees, inDegrees, order);
    end
    order = [order wardChosen];
    weightMat(:,wardChosen) = zeros(1,numWards);
end

